@@ -1,7 +1,8 @@
 """Handshake protocol."""
 
 from __future__ import annotations
-from typing import NamedTuple
+from contextlib import suppress
+from typing import IO, NamedTuple
 
 from mcipc.query.proto.common import MAGIC
 from mcipc.query.proto.common import random_session_id
@@ -9,7 +10,7 @@ from mcipc.query.proto.common import BigEndianSignedInt32
 from mcipc.query.proto.common import Type
 
 
-__all__ = ['Request', 'Response', 'HandshakeMixin']
+__all__ = ['Request', 'Response']
 
 
 class Request(NamedTuple):
@@ -26,6 +27,11 @@ class Request(NamedTuple):
         payload += bytes(self.session_id)
         return payload
 
+    @classmethod
+    def create(cls) -> Request:
+        """Creates a handshake with a random session ID."""
+        return cls(session_id=random_session_id())
+
 
 class Response(NamedTuple):
     """A server → client handshake response packet."""
@@ -35,12 +41,23 @@ class Response(NamedTuple):
     challenge_token: BigEndianSignedInt32
 
     @classmethod
-    def from_bytes(cls, bytes_: bytes) -> Response:
-        """Creates the packet from bytes."""
-        type_ = Type.from_bytes(bytes_[0:1])
-        session_id = BigEndianSignedInt32.from_bytes(bytes_[1:5])
+    def read(cls, file: IO) -> Response:
+        """Reads the response from a file-like object."""
+        type_ = Type.from_bytes(file.read(1))
+        session_id = BigEndianSignedInt32.from_bytes(file.read(4))
         # For challenge token, see: https://wiki.vg/Query#Handshake
-        challenge_token = BigEndianSignedInt32(bytes_[5:-1].decode())
+        bytes_ = b''
+
+        while True:
+            byte = file.read(1)
+
+            if byte == b'\x00':
+                with suppress(ValueError):
+                    challenge_token = BigEndianSignedInt32(bytes_.decode())
+                    break
+
+            bytes_ += byte
+
         return cls(type_, session_id, challenge_token)
 
     def to_json(self) -> dict:
@@ -50,18 +67,3 @@ class Response(NamedTuple):
             'session_id': self.session_id,
             'challenge_token': self.challenge_token
         }
-
-
-class HandshakeMixin:   # pylint: disable=R0903
-    """Query client mixin for performing handshakes."""
-
-    def handshake(self, *, set_challenge_token: bool = True) -> Response:
-        """Performs a handshake."""
-        request = Request(session_id=random_session_id())
-        bytes_ = self.communicate(bytes(request))
-        response = Response.from_bytes(bytes_)
-
-        if set_challenge_token:
-            self.challenge_token = response.challenge_token
-
-        return response
