@@ -5,7 +5,7 @@ from mcipc.rcon.proxy import CommandProxy
 from mcipc.rcon.types import Vec3
 
 
-__all__ = ['replaceitem']
+__all__ = ['ReplaceitemProxy', 'replaceitem']
 
 
 class ReplaceitemProxy(CommandProxy):
@@ -15,12 +15,15 @@ class ReplaceitemProxy(CommandProxy):
         """Replaces a block."""
         self._run('block', pos, slot, item, count)
 
-    def entity(self, targets: str, slot: str, item: str, count: int = None) -> str:
+    def entity(self, targets: str, slot: str, item: str,
+               count: int = None) -> str:
         """Replaces an entity."""
         self._run('entity', targets, slot, item, count)
 
 
 def replaceitem(self: Client) -> ReplaceitemProxy:
-    """Delegates to a command proxy."""
+    """Delegates to a
+    :py:class:`mcipc.rcon.je.commands.replaceitem.ReplaceitemProxy`
+    """
 
     return ReplaceitemProxy(self, 'replaceitem')
